@@ -1,5 +1,6 @@
 """djangocms-helper - Helpers for django CMS plugin development"""
 
-__version__ = '0.5.0'
+__version__ = '0.6.0'
 __author__ = 'Iacopo Spalletti <i.spalletti@nephila.it>'
-__all__ = []
+__all__ = ['runner']
+ 
