@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
 HELPER_SETTINGS = {
     'TIME_ZONE': 'Europe/Rome',
+    'INSTALLED_APPS': [
+        'example2'
+    ]
 }
