@@ -2,7 +2,6 @@
 from __future__ import print_function, with_statement
 from copy import copy
 from distutils.version import LooseVersion
-from django.utils.encoding import force_text
 import os
 import os.path
 import shutil
@@ -12,21 +11,19 @@ try:
 except ImportError:
     import unittest
 
-from cms.test_utils.tmpdir import temp_dir
 import django
+from django.utils.encoding import force_text
 
 from ..main import core, _make_settings
-from ..utils import work_in, captured_output, DJANGO_1_6, DJANGO_1_5
+from ..utils import work_in, captured_output, DJANGO_1_6, temp_dir
 
 DEFAULT_ARGS = {
     'shell': False,
     'test': False,
-    'check': False,
     'cms_check': False,
     'compilemessages': False,
     'makemessages': False,
     'makemigrations': False,
-    'squashmigrations': False,
     'pyflakes': False,
     'authors': False,
     'server': False,
@@ -41,7 +38,9 @@ DEFAULT_ARGS = {
     '--bind': '',
     '--port': '',
     '<test-label>': '',
-    '<extra-applications>': ''
+    '<extra-applications>': '',
+    'options': '',
+    '<command>': '',
 }
 
 
@@ -66,6 +65,10 @@ class CommandTests(unittest.TestCase):
                 cls.migration_dir_2 = os.path.abspath(os.path.join(cls.application_2, 'migrations'))
                 cls.migration_file = os.path.abspath(os.path.join(cls.application, 'migrations', '0001_initial.py'))
                 cls.migration_file_2 = os.path.abspath(os.path.join(cls.application_2, 'migrations', '0001_initial.py'))
+        try:
+            import cms
+        except ImportError:
+            DEFAULT_ARGS['--cms'] = False
 
     def setUp(self):
         try:
@@ -79,6 +82,9 @@ class CommandTests(unittest.TestCase):
         try:
             if self.migration_dir:
                 shutil.rmtree(self.migration_dir)
+        except (OSError, TypeError):
+            pass
+        try:
             if self.migration_dir_2:
                 shutil.rmtree(self.migration_dir_2)
         except (OSError, TypeError):
@@ -116,7 +122,7 @@ class CommandTests(unittest.TestCase):
                         # Testing that cms_helper.py in the command option is loaded
                         self.assertEqual(local_settings.TIME_ZONE, 'Europe/Paris')
                         # Existing application is kept
-                        self.assertTrue('mptt' in local_settings.INSTALLED_APPS)
+                        self.assertTrue('djangocms_helper.test_data' in local_settings.INSTALLED_APPS)
                         # New one is added
                         self.assertTrue('djangocms_admin_style' in local_settings.INSTALLED_APPS)
                         # Existing application is kept
@@ -175,23 +181,6 @@ class CommandTests(unittest.TestCase):
                     core(args, self.application)
                     self.assertTrue('No conflicts detected to merge' in out.getvalue())
 
-    def test_squashmigrations(self):
-        from django.core.exceptions import DjangoRuntimeWarning
-        from django.core.management import CommandError
-        with work_in(self.basedir):
-            with captured_output() as (out, err):
-                args = copy(DEFAULT_ARGS)
-                args['squashmigrations'] = True
-                args['<migration-name>'] = '0001_initial'
-                if DJANGO_1_6:
-                    with self.assertRaises(DjangoRuntimeWarning) as exit:
-                        core(args, self.application)
-                    self.assertEqual(force_text(exit.exception), 'Command not implemented for Django 1.6 and below')
-                else:
-                    with self.assertRaises(CommandError) as exit:
-                        core(args, self.application)
-                    self.assertTrue('squashmigrations on it makes no sense' in force_text(exit.exception))
-
     def test_makemessages(self):
         with work_in(self.basedir):
             with captured_output() as (out, err):
@@ -209,18 +198,11 @@ class CommandTests(unittest.TestCase):
                 core(args, self.application)
                 self.assertTrue(os.path.exists(self.mofile))
 
-    @unittest.skipIf(LooseVersion(django.get_version()) < LooseVersion('1.7'),
-                     reason='check command available for Django 1.7+ only')
-    def test_check(self):
-        with work_in(self.basedir):
-            with captured_output() as (out, err):
-                shutil.copy(self.poexample, self.pofile)
-                args = copy(DEFAULT_ARGS)
-                args['check'] = True
-                core(args, self.application)
-        self.assertTrue('no issues' in out.getvalue())
-
     def test_cms_check(self):
+        try:
+            import cms
+        except ImportError:
+            raise unittest.SkipTest('django CMS not available, skipping test')
         with work_in(self.basedir):
             with captured_output() as (out, err):
                 shutil.copy(self.poexample, self.pofile)
@@ -232,7 +214,47 @@ class CommandTests(unittest.TestCase):
             self.assertFalse('[WARNING]' in out.getvalue())
             self.assertFalse('[ERROR]' in out.getvalue())
 
+    @unittest.skipIf(LooseVersion(django.get_version()) < LooseVersion('1.7'),
+                     reason='check command available in Django 1.7+ only')
+    def test_any_command_check(self):
+        with work_in(self.basedir):
+            with captured_output() as (out, err):
+                pass
+                args = copy(DEFAULT_ARGS)
+                args['<command>'] = 'check'
+                args['options'] = ['helper', 'check', '--extra-settings=cms_helper_extra.py']
+                core(args, self.application)
+        self.assertTrue('no issues' in out.getvalue())
+
+    def test_any_command_compilemessages(self):
+        with work_in(os.path.join(self.basedir, self.application)):
+            with captured_output() as (out, err):
+                shutil.copy(self.poexample, self.pofile)
+                args = copy(DEFAULT_ARGS)
+                args['<command>'] = 'compilemessages'
+                args['options'] = 'helper compilemessages --cms -len --verbosity=2'.split(' ')
+                core(args, self.application)
+                self.assertTrue(os.path.exists(self.mofile))
+
+    @unittest.skipIf(LooseVersion(django.get_version()) < LooseVersion('1.7'),
+                     reason='makemigrations command available for Django 1.7+ only')
+    def test_any_command_migrations(self):
+        with work_in(self.basedir):
+            with captured_output() as (out, err):
+                args = copy(DEFAULT_ARGS)
+                args['<command>'] = 'makemigrations'
+                args['options'] = 'helper makemigrations example2 --verbosity=2'.split(' ')
+                core(args, self.application)
+            self.assertFalse('Create model ExampleModel1' in out.getvalue())
+            self.assertFalse(os.path.exists(self.migration_file))
+            self.assertTrue('Create model ExampleModel2' in out.getvalue())
+            self.assertTrue(os.path.exists(self.migration_file_2))
+
     def test_pyflakes(self):
+        try:
+            import cms
+        except ImportError:
+            raise unittest.SkipTest('django CMS not available, skipping test')
         with work_in(self.basedir):
             with captured_output() as (out, err):
                 args = copy(DEFAULT_ARGS)
@@ -255,6 +277,10 @@ class CommandTests(unittest.TestCase):
     @unittest.skipIf(sys.version_info < (2, 7),
                      reason="Example test non discoverable in Python 2.6")
     def test_testrun_nocms(self):
+        try:
+            import cms
+        except ImportError:
+            raise unittest.SkipTest('django CMS not available, skipping test')
         with work_in(self.basedir):
             with captured_output() as (out, err):
                 with self.assertRaises(SystemExit) as exit:
@@ -277,6 +303,10 @@ class CommandTests(unittest.TestCase):
         self.assertTrue('Authors (' in out.getvalue())
 
     def test_urls(self):
+        try:
+            import cms
+        except ImportError:
+            raise unittest.SkipTest('django CMS not available, skipping test')
         from django.core.urlresolvers import reverse
         with work_in(self.basedir):
             with captured_output() as (out, err):
