@@ -1,19 +1,28 @@
 # -*- coding: utf-8 -*-
 import contextlib
 from distutils.version import LooseVersion
-from django.core.management import call_command
 import os
 import random
 import shutil
 import stat
 import sys
 from tempfile import mkdtemp
+
 import django
+from django.core.management import call_command
 from django.core.urlresolvers import clear_url_caches
 from django.utils.datastructures import SortedDict
 from django.utils.functional import empty
 from django.utils.six import StringIO
 
+try:
+    import cms  # NOQA
+    CMS_31 = LooseVersion('3.1') <= LooseVersion(cms.__version__) < LooseVersion('3.2')
+    CMS_30 = LooseVersion('3.0') <= LooseVersion(cms.__version__) < LooseVersion('3.1')
+except ImportError:
+    CMS_31 = False
+    CMS_30 = False
+
 DJANGO_1_4 = LooseVersion(django.get_version()) < LooseVersion('1.5')
 DJANGO_1_5 = LooseVersion(django.get_version()) < LooseVersion('1.6')
 DJANGO_1_6 = LooseVersion(django.get_version()) < LooseVersion('1.7')
@@ -132,7 +141,6 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
 
     if args['--cms']:
         CMS_APPS = [
-            'mptt',
             'cms',
             'menus',
             'sekizai',
@@ -141,7 +149,7 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
             'djangocms_admin_style'
         ]
         CMS_PROCESSORS = [
-            'cms.context_processors.media',
+            'cms.context_processors.cms_settings',
             'sekizai.context_processors.sekizai',
             'django.contrib.messages.context_processors.messages',
         ]
@@ -158,6 +166,14 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
         CMS_MIDDLEWARE = []
         CMS_PROCESSORS = []
         URLCONF = 'djangocms_helper.urls'
+
+    if CMS_30:
+        CMS_1_7_MIGRATIONS = {
+            'cms': 'cms.migrations_django',
+            'menus': 'menus.migrations_django',
+        }
+    else:
+        CMS_1_7_MIGRATIONS = {}
     default_settings = get_default_settings(CMS_APPS, CMS_PROCESSORS,
                                             CMS_MIDDLEWARE, CMS_APP_STYLE,
                                             URLCONF, application)
@@ -189,12 +205,14 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
         apps = extra_settings.get('INSTALLED_APPS', [])
         template_processors = extra_settings.get('TEMPLATE_CONTEXT_PROCESSORS', [])
         middleware = extra_settings.get('MIDDLEWARE_CLASSES', [])
-        if apps:
+        if 'INSTALLED_APPS' in extra_settings:
             del(extra_settings['INSTALLED_APPS'])
-        if template_processors:
+        if 'TEMPLATE_CONTEXT_PROCESSORS' in extra_settings:
             del(extra_settings['TEMPLATE_CONTEXT_PROCESSORS'])
-        if middleware:
+        if 'MIDDLEWARE_CLASSES' in extra_settings:
             del(extra_settings['MIDDLEWARE_CLASSES'])
+        if application in default_settings['INSTALLED_APPS'] and application in apps:
+            default_settings['INSTALLED_APPS'].remove(application)
         default_settings.update(extra_settings)
         default_settings['INSTALLED_APPS'].extend(apps)
         default_settings['TEMPLATE_CONTEXT_PROCESSORS'].extend(template_processors)
@@ -202,6 +220,17 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
 
     if DJANGO_1_6:
         default_settings['INSTALLED_APPS'].append('south')
+    elif args['--cms']:
+        default_settings['MIGRATION_MODULES'].update(CMS_1_7_MIGRATIONS)
+    if CMS_31:
+        if 'treebeard' not in default_settings['INSTALLED_APPS']:
+            default_settings['INSTALLED_APPS'].append('treebeard')
+        if ('filer' in default_settings['INSTALLED_APPS'] and 
+                'mptt' not in default_settings['INSTALLED_APPS']):
+            default_settings['INSTALLED_APPS'].append('mptt')
+    else:
+        if 'mptt' not in default_settings['INSTALLED_APPS']:
+            default_settings['INSTALLED_APPS'].append('mptt')
 
     # Support for custom user models
     if django.VERSION >= (1, 5) and 'AUTH_USER_MODEL' in os.environ:
@@ -215,6 +244,8 @@ def _make_settings(args, application, settings, STATIC_ROOT, MEDIA_ROOT):
 
     _reset_django(settings)
     settings.configure(**default_settings)
+    if not DJANGO_1_6:
+        django.setup()
     if 'south' in settings.INSTALLED_APPS:
         from south.management.commands import patch_for_test_db_setup
         patch_for_test_db_setup()
@@ -245,11 +276,21 @@ def _create_db(migrate_cmd=False):
             call_command("migrate", interactive=False, verbosity=1, database='default',
                          fake=True)
     else:
-        call_command("migrate", database='default')
+        call_command("migrate")
+
+
+def get_user_model():
+    # Django 1.5+ compatibility
+    if django.VERSION >= (1, 5):
+        from django.contrib.auth import get_user_model
+    else:
+        from django.contrib.auth.models import User
+        User.USERNAME_FIELD = 'username'
+        get_user_model = lambda: User
+    return get_user_model()
 
 
 def create_user(username, email, password, is_staff=False, is_superuser=False):
-    from cms.utils.compat.dj import get_user_model
     User = get_user_model()
     usr = User()
 
@@ -268,7 +309,6 @@ def create_user(username, email, password, is_staff=False, is_superuser=False):
 
 
 def get_user_model_labels():
-    from cms.utils.compat.dj import get_user_model
     User = get_user_model()
 
     user_orm_label = '%s.%s' % (User._meta.app_label, User._meta.object_name)
